
################################################################################
#                 Installing Libraries and Checking Function                   #
#                             Julie (Jules) Gilbert                            #
################################################################################

# First, check if "base R" has been installed correctly

R.Version()
# if this works correctly, information regarding the version of R you have installed
# should appear in the "Console" window below

x <- 7
# assign a value to a variable. if this works correctly, you should see an "x" and 
# a "7" in the "Environment" window to the right, under the "Values" header

sum(x, 3)
# calculate a sum. if this works correctly, "10" should show up below in the 
# "Console" window

################################################################################

# While the base R system has a lot of functionality, there are different libraries 
# (or packages) that have been developed to make certain tasks easier or to do 
# tasks specific to certain fields or to interface with specific machines/systems

# For the workshop, you will need quite a few libraries installed. To install them, 
# run the following command:

install.packages("conflicted")
install.packages("dtplyr")
install.packages("tidyverse")
install.packages("lubridate")
install.packages("ggplot2")
install.packages("openxlsx") 
install.packages("leaflet") 
install.packages("tigris") 
install.packages("sf") 
install.packages("htmlwidgets") 
install.packages("reshape2")
install.packages("stringr") 
install.packages("RSocrata") 
install.packages("jsonlite") 
install.packages("httr")

# if you have a mac, install this:
install.packages("cronR")
# if you have a windows computer, install this:
install.packages("taskscheduleR")

# note: this installation process will likely take a long period of time

#####
# then, load the libraries. after each load, we'll confirm proper loading by running one 
# function specific to each library.

library(tidyverse)

sample_dataframe <- data.frame(x = c(1, 2, 3), y = c("a", "b", "b"))
sample_dataframe <- sample_dataframe %>% select(x)
# after this step, instead of sample dataframe having two columns, x and y, 
# it should only have one column, x

library(lubridate)

a_date <- as_date("2023-05-23") # just converts the character string to a date-type

library(ggplot2)

sample_dataframe <- data.frame(y = c(1, 2, 3), x = c("a", "b", "b"))

ggplot(sample_dataframe, aes(x = x, y = y)) + 
  geom_point()
# a small plot should appear in the "Plots" window in the lower right-hand corner

library(openxlsx)
wb <- createWorkbook()
# creates an excel workbook R object called "wb"

library(leaflet)

m <- leaflet() %>%
  addTiles() %>%  # Add default OpenStreetMap map tiles
  addMarkers(lng=174.768, lat=-36.852, popup="The birthplace of R")
m  # Print the map
# creates a basic map showing a portion of New Zealand

library(tigris)

manhattan_roads <- roads("NY", "New York")
# returns an sf object of manhattan roads
# should see object called manhattan roads in "Environment" window in upper
# right hand corner

library(sf)

nc <- st_read(system.file("shape/nc.shp", package="sf"))
# should print paragraph starting with "Reading" and ending with 
# "Geodetic"

library(htmlwidgets)

JS('1 + 1')
# should print
# [1] "1 + 1"
# attr(,"class")
# [1] "JS_EVAL"

library(reshape2)

melt(sample_dataframe, id.vars = c("x"))
# should print dataframe
# x variable value
# a        y     1
# b        y     2
# b        y     3

library(stringr)

x <- c("why", "video", "cross", "extra", "deal", "authority")
str_length(x) 
# should print out 3 5 5 5 4 9

library(RSocrata)

earthquakesDataFrame <- read.socrata("https://soda.demo.socrata.com/dataset/USGS-Earthquakes-for-2012-11-01-API-School-Demo/4334-bgaj")
nrow(earthquakesDataFrame) 
# should print out 1007

library(jsonlite)

all.equal(mtcars, fromJSON(toJSON(mtcars)))
# should print "TRUE"

library(httr)

r <- GET("http://httpbin.org/get")
# should create an item called "r" with "List of 10" in "Environment" window
# in upper right hand corner


##### if you have a mac, run this:
library(cronR)
cron_ls()
# lists active cron jobs

##### if you have a windows computer, run this:
library(taskscheduleR)
taskscheduler_ls()
# lists active scheduled tasks

################################################################################
# Congratulations! If all of the above code has run without errors, then you 
# should be all set-up to participate in the R Workshop!
